@@ -153,7 +153,7 @@ sub new {
 	$be = __PACKAGE__."::Pango";
     }
     eval "require $be" or croak($@);
-
+    Text::Layout::FontConfig->set_loader( $be->can("load_font") );
     bless { _be      => $be,
 	    _context => $be->init(@data),
 	    _fonts   => {},
@@ -368,7 +368,6 @@ sub set_markup {
 		# <span face="Sans">
 		elsif ( $k =~ /^(face|font_family)$/ ) {
 		    $fcur = Text::Layout::FontConfig->find_font($v);
-		    $self->_load_font($fcur);
 		}
 
 		# <span size=20>
@@ -389,7 +388,6 @@ sub set_markup {
 		    $v = Text::Layout::FontConfig::_norm_style($v);
 		    $fcur = Text::Layout::FontConfig->find_font( $fcur->{family},
 					      $v, $fcur->{weight} );
-		    $self->_load_font($fcur);
 		}
 
 		# <span weight="bold">
@@ -397,7 +395,6 @@ sub set_markup {
 		    $v = Text::Layout::FontConfig::_norm_weight($v);
 		    $fcur = Text::Layout::FontConfig->find_font( $fcur->{family},
 					      $fcur->{style}, $v );
-		    $self->_load_font($fcur);
 		}
 
 		# <span variant="...">
@@ -618,23 +615,14 @@ $description is a Text::Layout::FontConfig object.
 
 sub set_font_description {
     my ( $self, $description ) = @_;
-    my $o = "Text::Layout::FontConfig";
+    my $o = "Text::Layout::FontDescriptor";
     croak("set_font_description requires a $o object (not $description)")
       unless UNIVERSAL::isa( $description, $o );
 
-    $self->_load_font( $description );
-    $self->set_font( $description );
-    $self->set_font_size($description->{size})
+    $self->{_currentfont}  = $description;
+    $self->{_currentsize}  = $description->{size}
       if $description->{size};
-}
-
-sub _load_font {
-    my ( $self, $description ) = @_;
-    my $font;
-    if ( !$description->{font} && ( $font = $description->{load} ) ) {
-	no strict 'refs';
-	"$self->{_be}::load_font"->( $self, $description );
-    }
+    $self->{_currentcolor} = $description->{color} || "black";
 }
 
 =over
@@ -1153,9 +1141,10 @@ Computes the logical and ink extents of the layout.
 
 Logical extents are usually what you want for positioning things.
 
-Return value is an array (not a ref!) containing two array refs with 4
-values: C<x>, C<y>, C<width>, and C<height>. The first reflects the
-ink extents, the second the logical extents.
+Return value is an array (in list context) or an array ref (in scalar
+context) containing two hash refs with 4 values: C<x>, C<y>, C<width>,
+and C<height>. The first reflects the ink extents, the second the
+logical extents.
 
 C<x> will reflect the offset when text is centered or right aligned.
 It will be zero for left aligned text. For right aligned text, it will
@@ -1175,8 +1164,8 @@ sub get_extents {
     my ( $self ) = @_;
 
     my @bb = @{$self->get_bbox};
-    my $res = [ $bb[0], 0, $bb[2], $bb[3]-$bb[1] ];
-    return ( $res, $res );
+    my $res = { x => $bb[0], y => 0, width => $bb[2], height => $bb[3]-$bb[1] };
+    return wantarray ? ( $res, $res ) : [ $res, $res ];
 }
 
 =over
@@ -1193,8 +1182,8 @@ sub get_pixel_extents {
     my ( $self ) = @_;
 
     my @bb = @{$self->get_pixel_bbox};
-    my $res = [ $bb[0], 0, $bb[2], $bb[3]-$bb[1] ];
-    return ( $res, $res );
+    my $res = { x => $bb[0], y => 0, width => $bb[2], height => $bb[3]-$bb[1] };
+    return wantarray ? ( $res, $res ) : [ $res, $res ];
 }
 
 =over
@@ -1215,7 +1204,7 @@ returned.
 
 sub get_size {
     my ( $self ) = @_;
-    my $e = $self->get_extents->[1];
+    my $e = ($self->get_extents)[1];
     wantarray
       ? return ( $e->{width}, $e->{height} )
       : return { width => $e->{width}, height => $e->{height} };
@@ -1233,7 +1222,7 @@ Same as get_size().
 
 sub get_pixel_size {
     my ( $self ) = @_;
-    my $e = $self->get_pixel_extents->[1];
+    my $e = ($self->get_pixel_extents)[1];
     wantarray
       ? return ( $e->{width}, $e->{height} )
       : return { width => $e->{width}, height => $e->{height} };
@@ -1346,22 +1335,6 @@ sub get_font_size {
 
 =over
 
-=item set_font( $font )
-
-Designates a font for this layout using an internal font.
-
-=back
-
-=cut
-
-sub set_font {
-    my ( $self, $font ) = @_;
-    $self->{_currentfont}  = $font;
-    $self->{_currentcolor} = $font->{color} || "black";
-}
-
-=over
-
 =item get_bbox
 
 Returns the bounding box of the text, w.r.t. the origin.
@@ -1473,8 +1446,6 @@ sub nyi {
     croak("Method \"" . (caller(1))[3] . "\" not implemented");
 }
 
-=back
-
 =head1 SEE ALSO
 
 Description of the Pango Markup Language:
@@ -1501,8 +1472,6 @@ You can find documentation for this module with the perldoc command.
 Please report any bugs or feature requests using the issue tracker on
 GitHub.
 
-=back
-
 =head1 LICENSE
 
 Copyright (C) 2019, Johan Vromans
