@@ -90,7 +90,9 @@ sub get_font {
     $self->{font} ||= do {
 	croak("Forgot to pass a layout context to get_font?")
 	  unless UNIVERSAL::isa( $context, 'Text::Layout' );
-	$context->load_font( $self->{loader_data}, $self );
+	croak("Cannot load font $self (no loader defined)")
+	  unless $self->{loader};
+	$self->{loader}->( $self, $context, $self->{loader_data} );
     };
 }
 
@@ -102,7 +104,7 @@ sub get_font {
 
 =item get_weight
 
-Accessors to the font family, style, and weight.
+Accessors to the font family, style. and weight.
 
 Readonly.
 
@@ -125,6 +127,11 @@ sub get_weight {
     $self->{weight};
 }
 
+sub get_size {
+    my ( $self ) = @_;
+    $self->{size};
+}
+
 =over
 
 =item set_size
@@ -142,80 +149,6 @@ sub set_size {
     $self->{size} = $size;
 }
 
-sub get_size {
-    my ( $self ) = @_;
-    $self->{size};
-}
-
-=item set_direction
-
-=item get_direction
-
-Sets/gets the direction property of the font.
-
-=back
-
-=cut
-
-sub set_direction {
-    my ( $self, $direction ) = @_;
-    $self->{direction} = $direction;
-}
-
-sub get_direction {
-    my ( $self ) = @_;
-    $self->{direction};
-}
-
-# Not documented -- internal use only.
-
-sub set_shaping {
-    my ( $self, $sh ) = @_;
-    $self->{shaping} = $sh // 1;
-}
-
-sub get_shaping {
-    my ( $self ) = @_;
-    $self->{shaping};
-}
-
-# Not documented -- internal use only.
-
-sub set_interline {
-    my ( $self, $sh ) = @_;
-    $self->{interline} = $sh // 1;
-}
-
-sub get_interline {
-    my ( $self ) = @_;
-    $self->{interline};
-}
-
-# Not documented -- internal use only.
-
-# Note that the ascender/descender values are filled in at load time,
-# unless overridden by a set_... call.
-
-sub set_ascender {
-    my ( $self, $asc ) = @_;
-    $self->{ascender} = $asc;
-}
-
-sub get_ascender {
-    my ( $self ) = @_;
-    $self->{ascender};
-}
-
-sub set_descender {
-    my ( $self, $desc ) = @_;
-    $self->{descender} = $desc;
-}
-
-sub get_descender {
-    my ( $self ) = @_;
-    $self->{descender};
-}
-
 =over
 
 =item to_string
@@ -258,7 +191,8 @@ You can find documentation for this module with the perldoc command.
 
   perldoc Text::Layout::FontDescriptor
 
-Please report any bugs or feature requests using the issue tracker for Text::Layout on GitHub.
+Please report any bugs or feature requests using the issue tracker on
+GitHub.
 
 =head1 LICENSE
 
